pub type EventMatchList = Vec<EventMatchListItem>;Expand description
A list of matches belonging to a particular event.
Aliased Type
pub struct EventMatchList { /* private fields */ }pub type EventMatchList = Vec<EventMatchListItem>;A list of matches belonging to a particular event.
pub struct EventMatchList { /* private fields */ }